#!/bin/sh
# postinst script for netfpga
#
# see: dh_installdeb(1)

set -e

# summary of how this script can be called:
#        * <postinst> `configure' <most-recently-configured-version>
#        * <old-postinst> `abort-upgrade' <new version>
#        * <conflictor's-postinst> `abort-remove' `in-favour' <package>
#          <new-version>
#        * <postinst> `abort-remove'
#        * <deconfigured's-postinst> `abort-deconfigure' `in-favour'
#          <failed-install-package> <version> `removing'
#          <conflicting-package> <version>
# for details, see http://www.debian.org/doc/debian-policy/ or
# the debian-policy package

# Define a gigabyte and NetFPGA kernel parameter for grub update 
GIGABYTE=1048576
GRUB_FILE=/etc/default/grub
NETFPGA_COMMENT='# NetFPGA module vmalloc changes'
NETFPGA_VALLOC_LINE='GRUB_CMDLINE_LINUX="vmalloc=256MB"'


case "$1" in
    configure)

	MEMSIZE=`cat /proc/meminfo | grep MemTotal | awk '{print $2}'`
	echo $MEMSIZE

	if [ $MEMSIZE -ge $GIGABYTE ] ; then
        	echo "You have 1GB of RAM or more"
        	num_nfpga_comment=`grep -c "$NETFPGA_COMMENT" $GRUB_FILE`
	        num_vmalloc_entr=`grep -c '^GRUB_CMDLINE_LINUX[[:space:]]*=[[:space:]]*"vmalloc[[:space:]]*=[[:space:]]*256MB"' $GRUB_FILE`

       		if [ $num_nfpga_comment -eq 0 -a  $num_vmalloc_entr -eq 0 ] ; then
                	echo "Didn't find any parameter"
	                num_any_vmalloc=`grep -c '^GRUB_CMDLINE_LINUX[[:space:]]*=[[:space:]]*"vmalloc[[:space:]]*=' $GRUB_FILE`
	                if [ $num_any_vmalloc -eq 0 ] ; then
       		                echo "$NETFPGA_COMMENT" >> $GRUB_FILE
	                        echo "$NETFPGA_VALLOC_LINE" >> $GRUB_FILE
	                        update-grub

       		         fi
	        else
       		         echo "The NetFPGA module vmalloc parameter for the kernel already presents"
        	fi
	else
       		 echo "You have less than 1GB of RAM"
	fi
    ;;

    abort-upgrade|abort-remove|abort-deconfigure)
    ;;

    *)
        echo "postinst called with unknown argument \`$1'" >&2
        exit 1
    ;;
esac

# dh_installdeb will replace this with shell code automatically
# generated by other debhelper scripts.

#DEBHELPER#

exit 0
